@@ -48,6 +48,14 @@ class CallbackSignatureError(Exception):
     pass
 
 
+class CallbackCheckAborted(Exception):
+    """
+    Used by callback_check to signal that signature check is unfeasible because
+    the user passed a DottedPath whose underlying function hasn't been imported
+    """
+    pass
+
+
 class UpstreamKeyError(Exception):
     """
     Raised when trying to get an upstream dependency that does not exist,
@@ -100,6 +108,14 @@ class RemoteFileNotFound(Exception):
     pass
 
 
+class MissingClientError(Exception):
+    """
+    Raised when failing to get a valid task-level or dag-level client
+    for a Task or Product
+    """
+    pass
+
+
 def display_errors(errors):
     return '\n'.join(f'{_display_error_loc(e)} ({e["msg"]})' for e in errors)
 
